<!DOCTYPE html>
<html lang="fr">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Sentipede {version}</title>
    <link rel="stylesheet" href="/templates/style.css">
</head>
<body>
    <div class="container">
        <header style="margin-bottom: 25px;">
            <span style="color: var(--accent); font-weight: bold;">Root</span>
            <span style="color: #d6dae0;">:</span>
            <span style="color: var(--link);" id="currentPath">{displaypath}</span>
        </header>
        
        <div class="controls-row">
            <div class="control-group">
                <span style="color: #d6dae0; font-size: 0.8em;">MODE</span>
                <button class="mode-btn active" onclick="switchMode('exfil')" id="btnExfil">OUT</button>
                <button class="mode-btn" onclick="switchMode('infil')" id="btnInfil">IN</button>
                <button class="mode-btn" onclick="switchMode('relay')" id="btnRelay">RELAY</button>
            </div>
            
            <div class="control-group">
                <span style="color: #d6dae0; font-size: 0.8em;">TARGET OS</span>
                <button class="mode-btn os-btn active" data-os="linux" onclick="switchOS('linux')" id="btnLinux">LINUX</button>
                <button class="mode-btn os-btn" data-os="windows" onclick="switchOS('windows')" id="btnWindows">WINDOWS</button>
            </div>
        </div>
        
        <div class="control-group" style="margin-bottom: 20px;">
            <span style="color: #d6dae0; font-size: 0.8em;">INTERFACE</span>
            <div class="interface-selector" style="flex-grow: 1;">
                <select id="interfaceSelect" onchange="updateInterface()">
                    <option value="">Loading...</option>
                </select>
            </div>
        </div>
        
        <div id="exfilSection">
            {file_list}
        </div>

        <div id="infilSection" class="hidden">
            <div class="upload-section">
                <div style="margin-bottom: 15px; color: var(--accent); font-weight: bold; border-bottom: 1px solid var(--border); padding-bottom: 10px;">
                    📤 RECEIVE A FILE (<span id="osDisplay">LINUX</span>)
                </div>
                <div class="file-input">
                    <input type="text" id="targetFile" placeholder="Target file path..." />
                    <button class="generate-btn" onclick="generateUploadCommands()">GENERATE</button>
                </div>
                <div id="uploadCommands"></div>
            </div>
        </div>
        
        <div id="relaySection" class="hidden">
            <div class="filter-bar">
                <input type="text" id="toolSearch" placeholder="Search tool..." onkeyup="filterTools()">
            </div>
            <div id="toolsList" class="tools-grid">
                </div>
        </div>

        <footer>By <a href="https://github.com/b3rt1ng" target="_blank">b3rt1ng</a></footer>
    </div>

    <script src="/templates/app.js"></script>
</body>
</html>

